summaryrefslogtreecommitdiff
path: root/lisp/progmodes/python.el
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2020-07-11 09:25:04 -0700
committerGlenn Morris <rgm@gnu.org>2020-07-11 09:25:04 -0700
commit398a2680616112675afe26478706a3cea9e76158 (patch)
tree24751dcc7238b3b65612f670569f10484f1d9fcd /lisp/progmodes/python.el
parent6cc35829e4772479abed1f46f0c51daa24d070e0 (diff)
parentc04b92104c2bc4c1a719e06fbe11045a204c36a0 (diff)
Merge from origin/emacs-27
c04b92104c Add commentary in gtkutil.c 6290850dac Consistently stylize eldoc as ElDoc in prose 136e931189 Improve documentation of "C-u C-x =" 1f52771fd3 Mention floating rounding issues c892ae65b4 Repair global-auto-revert-ignore-modes (bug#42271) 3a446a02fb ; * src/xdisp.c (decode_mode_spec): Fix commentary. 79f381b4a6 One more improvement of left/right-fringe display spec docs 1279bdb072 Another clarification of left/right-fringe display spec # Conflicts: # doc/emacs/programs.texi
Diffstat (limited to 'lisp/progmodes/python.el')
-rw-r--r--lisp/progmodes/python.el8
1 files changed, 4 insertions, 4 deletions
diff --git a/lisp/progmodes/python.el b/lisp/progmodes/python.el
index 165463aef59..3af55be4a19 100644
--- a/lisp/progmodes/python.el
+++ b/lisp/progmodes/python.el
@@ -34,7 +34,7 @@
;; Implements Syntax highlighting, Indentation, Movement, Shell
;; interaction, Shell completion, Shell virtualenv support, Shell
;; package support, Shell syntax highlighting, Pdb tracking, Symbol
;; completion, Skeletons, FFAP, Code Check, Eldoc, Imenu.
;; Syntax highlighting: Fontification of code is provided and supports
;; python's triple quoted strings properly.
@@ -216,7 +216,7 @@
;; Code check: Check the current file for errors with `python-check'
;; using the program defined in `python-check-command'.
;; Eldoc: returns documentation for object at point by using the
;; inferior python subprocess to inspect its documentation. As you
;; might guessed you should run `python-shell-send-buffer' from time
;; to time to get better results too.
@@ -4474,7 +4474,7 @@ See `python-check-command' for the default."
(format python-check-buffer-name command)))))
-;;; Eldoc
+;;; ElDoc
(defcustom python-eldoc-setup-code
"def __PYDOC_get_help(obj):
@@ -4591,7 +4591,7 @@ fetching."
(with-timeout (python-eldoc-function-timeout
(if python-eldoc-function-timeout-permanent
(progn
- (message "Eldoc echo-area display muted in this buffer, see `python-eldoc-function'")
+ (message "ElDoc echo-area display muted in this buffer, see `python-eldoc-function'")
(setq python-eldoc-get-doc nil))
(message "`python-eldoc-function' timed out, see `python-eldoc-function-timeout'")))
(python-eldoc--get-doc-at-point))))
@@ -34,7 +34,7 @@
;; interaction, Shell completion, Shell virtualenv support, Shell
;; package support, Shell syntax highlighting, Pdb tracking, Symbol
-;; completion, Skeletons, FFAP, Code Check, Eldoc, Imenu.
+;; completion, Skeletons, FFAP, Code Check, ElDoc, Imenu.
;; Syntax highlighting: Fontification of code is provided and supports
;; python's triple quoted strings properly.
@@ -216,7 +216,7 @@
;; Code check: Check the current file for errors with `python-check'
;; using the program defined in `python-check-command'.
-;; Eldoc: returns documentation for object at point by using the
+;; ElDoc: returns documentation for object at point by using the
;; inferior python subprocess to inspect its documentation. As you
;; might guessed you should run `python-shell-send-buffer' from time